@@ -1,6 +1,7 @@
 package org.ovirt.engine.core.common.action;
 
 import java.util.HashMap;
+import java.util.Map;
 
 import org.ovirt.engine.core.common.businessentities.ActionGroup;
 
@@ -18,24 +19,28 @@ public enum ActionType {
     StopVm(7, ActionGroup.STOP_VM, QuotaDependency.BOTH),
     ShutdownVm(8, ActionGroup.SHUT_DOWN_VM, QuotaDependency.CLUSTER),
     ChangeDisk(9, ActionGroup.CHANGE_VM_CD, QuotaDependency.NONE),
-    PauseVm(10, QuotaDependency.NONE),
     HibernateVm(11, ActionGroup.HIBERNATE_VM, QuotaDependency.NONE),
     RunVm(12, ActionGroup.RUN_VM, QuotaDependency.CLUSTER),
     RunVmOnce(13, ActionGroup.RUN_VM, QuotaDependency.BOTH),
     MigrateVm(14, ActionGroup.MIGRATE_VM, QuotaDependency.NONE),
     MigrateVmToServer(16, ActionGroup.MIGRATE_VM, QuotaDependency.NONE),
+    MigrateMultipleVms(66, ActionGroup.MIGRATE_VM, false, QuotaDependency.NONE),
     ReorderVmNics(17, ActionGroup.CREATE_VM, false, QuotaDependency.NONE),
     VmLogon(18, ActionGroup.CONNECT_TO_VM, QuotaDependency.NONE),
     SetVmTicket(22, ActionGroup.CONNECT_TO_VM, false, QuotaDependency.NONE),
     ExportVm(23, ActionGroup.IMPORT_EXPORT_VM, QuotaDependency.NONE),
     ExportVmTemplate(24, ActionGroup.IMPORT_EXPORT_VM, QuotaDependency.NONE),
     RestoreStatelessVm(25, QuotaDependency.NONE),
+    ExportVmToOva(26, ActionGroup.IMPORT_EXPORT_VM, QuotaDependency.NONE),
+    CreateOva(27, QuotaDependency.NONE),
     AddVmInterface(28, ActionGroup.CONFIGURE_VM_NETWORK, false, QuotaDependency.NONE),
     RemoveVmInterface(29, ActionGroup.CONFIGURE_VM_NETWORK, false, QuotaDependency.NONE),
     UpdateVmInterface(30, ActionGroup.CONFIGURE_VM_NETWORK, false, QuotaDependency.NONE),
     AddDisk(31, ActionGroup.CONFIGURE_VM_STORAGE, QuotaDependency.STORAGE),
     RegisterDisk(32, ActionGroup.CONFIGURE_VM_STORAGE, QuotaDependency.STORAGE),
-    UpdateVmDisk(34, ActionGroup.CONFIGURE_VM_STORAGE, false, QuotaDependency.STORAGE),
+    ExtractOva(33, QuotaDependency.NONE),
+    UpdateDisk(34, ActionGroup.CONFIGURE_VM_STORAGE, false, QuotaDependency.STORAGE),
+    ExportVmTemplateToOva(35, ActionGroup.IMPORT_EXPORT_VM, QuotaDependency.NONE),
     AttachDiskToVm(180, ActionGroup.CONFIGURE_VM_STORAGE, false, QuotaDependency.NONE),
     DetachDiskFromVm(181, ActionGroup.CONFIGURE_VM_STORAGE, false, QuotaDependency.NONE),
     HotPlugDiskToVm(182, ActionGroup.CONFIGURE_VM_STORAGE, false, QuotaDependency.NONE),
@@ -47,11 +52,14 @@ public enum ActionType {
     RemoveVmFromImportExport(37, ActionGroup.DELETE_VM, QuotaDependency.NONE),
     RemoveVmTemplateFromImportExport(38, ActionGroup.DELETE_TEMPLATE, QuotaDependency.NONE),
     ImportVmTemplate(39, ActionGroup.IMPORT_EXPORT_VM, QuotaDependency.STORAGE),
+    ImportVmTemplateFromOva(64, ActionGroup.IMPORT_EXPORT_VM, QuotaDependency.STORAGE),
+    AddDiskToTemplate(65, ActionGroup.CONFIGURE_VM_STORAGE, QuotaDependency.STORAGE),
     ChangeVMCluster(40, ActionGroup.EDIT_VM_PROPERTIES, false, QuotaDependency.NONE),
     CancelMigrateVm(41, ActionGroup.MIGRATE_VM, false, QuotaDependency.NONE),
     ActivateDeactivateVmNic(42, QuotaDependency.NONE),
     AddVmFromSnapshot(52, ActionGroup.CREATE_VM, QuotaDependency.BOTH),
     CloneVm(53, ActionGroup.CREATE_VM, QuotaDependency.BOTH),
+    CloneVmNoCollapse(56, ActionGroup.CREATE_VM, QuotaDependency.BOTH),
     ImportVmFromConfiguration(43, ActionGroup.IMPORT_EXPORT_VM, QuotaDependency.STORAGE),
     UpdateVmVersion(44, QuotaDependency.NONE),
     ImportVmTemplateFromConfiguration(45, ActionGroup.IMPORT_EXPORT_VM, QuotaDependency.STORAGE),
@@ -65,6 +73,9 @@ public enum ActionType {
     AddVmNicFilterParameter(60, ActionGroup.CONFIGURE_VM_NETWORK, false, QuotaDependency.NONE),
     UpdateVmNicFilterParameter(61, ActionGroup.CONFIGURE_VM_NETWORK, false, QuotaDependency.NONE),
     RemoveVmNicFilterParameter(62, ActionGroup.CONFIGURE_VM_NETWORK, false, QuotaDependency.NONE),
+    UpdateConvertedVm(63, QuotaDependency.NONE),
+    RemoveUnregisteredVmTemplate(67, ActionGroup.DELETE_TEMPLATE, QuotaDependency.NONE),
+    RemoveUnregisteredVm(68, ActionGroup.DELETE_VM, QuotaDependency.NONE),
 
     // VdsCommands
     AddVds(101, ActionGroup.CREATE_HOST, QuotaDependency.NONE),
@@ -93,9 +104,7 @@ public enum ActionType {
     RefreshHostCapabilities(126, ActionGroup.MANIPULATE_HOST, false, QuotaDependency.NONE),
     SshSoftFencing(127, QuotaDependency.NONE),
     VdsPowerDown(128, ActionGroup.MANIPULATE_HOST, QuotaDependency.NONE),
-    UpgradeOvirtNodeInternal(129, QuotaDependency.NONE),
     InstallVds(130, ActionGroup.EDIT_HOST_CONFIGURATION, false, QuotaDependency.NONE),
-    UpgradeOvirtNode(131, ActionGroup.EDIT_HOST_CONFIGURATION, false, QuotaDependency.NONE),
     VdsKdumpDetection(132, QuotaDependency.NONE),
     AddFenceAgent(133, ActionGroup.EDIT_HOST_CONFIGURATION, QuotaDependency.NONE),
     RemoveFenceAgent(134, ActionGroup.EDIT_HOST_CONFIGURATION, QuotaDependency.NONE),
@@ -109,10 +118,12 @@ public enum ActionType {
     HostUpgradeCheckInternal(142, QuotaDependency.NONE),
 
     // Network
-    AddNetwork(154, ActionGroup.CREATE_STORAGE_POOL_NETWORK, false, QuotaDependency.NONE),
-    RemoveNetwork(155, ActionGroup.CONFIGURE_STORAGE_POOL_NETWORK, false, QuotaDependency.NONE),
-    UpdateNetwork(156, ActionGroup.CONFIGURE_STORAGE_POOL_NETWORK, false, QuotaDependency.NONE),
+    AddNetwork(154, ActionGroup.CREATE_STORAGE_POOL_NETWORK, QuotaDependency.NONE),
+    RemoveNetwork(155, ActionGroup.CONFIGURE_STORAGE_POOL_NETWORK, QuotaDependency.NONE),
+    UpdateNetwork(156, ActionGroup.CONFIGURE_STORAGE_POOL_NETWORK, QuotaDependency.NONE),
     CommitNetworkChanges(157, ActionGroup.CONFIGURE_HOST_NETWORK, QuotaDependency.NONE),
+    ImportExternalNetwork(158, ActionGroup.CREATE_STORAGE_POOL_NETWORK, false, QuotaDependency.NONE),
+    InternalImportExternalNetwork(159, QuotaDependency.NONE),
 
     // VnicProfile Commands
     AddVnicProfile(160, ActionGroup.CREATE_NETWORK_VNIC_PROFILE, false, QuotaDependency.NONE),
@@ -124,7 +135,7 @@ public enum ActionType {
     UnlabelNetwork(164, ActionGroup.CONFIGURE_STORAGE_POOL_NETWORK, false, QuotaDependency.NONE),
     LabelNic(165, ActionGroup.CONFIGURE_HOST_NETWORK, false, QuotaDependency.NONE),
     UnlabelNic(166, ActionGroup.CONFIGURE_HOST_NETWORK, false, QuotaDependency.NONE),
-    PropagateNetworksToClusterHosts(167, false, QuotaDependency.NONE),
+    PropagateNetworksToClusterHosts(167, QuotaDependency.NONE),
 
     // SR-IOV
     UpdateHostNicVfsConfig(175, ActionGroup.CONFIGURE_HOST_NETWORK, false, QuotaDependency.NONE),
@@ -152,7 +163,7 @@ public enum ActionType {
     // ImagesCommands
     TryBackToSnapshot(204, QuotaDependency.NONE),
     RestoreFromSnapshot(205, QuotaDependency.STORAGE),
-    CreateAllSnapshotsFromVm(206, ActionGroup.MANIPULATE_VM_SNAPSHOTS, QuotaDependency.STORAGE),
+    CreateSnapshotForVm(206, ActionGroup.MANIPULATE_VM_SNAPSHOTS, QuotaDependency.STORAGE),
     CreateSnapshot(207, QuotaDependency.STORAGE),
     CreateSnapshotFromTemplate(208, QuotaDependency.STORAGE),
     CreateImageTemplate(209, QuotaDependency.STORAGE),
@@ -166,11 +177,9 @@ public enum ActionType {
     RestoreAllSnapshots(224, ActionGroup.MANIPULATE_VM_SNAPSHOTS, QuotaDependency.STORAGE),
     CopyImageGroup(225, QuotaDependency.STORAGE),
     MoveOrCopyDisk(228, QuotaDependency.STORAGE),
-    RemoveSnapshotSingleDisk(227, QuotaDependency.STORAGE),
     CreateCloneOfTemplate(229, QuotaDependency.STORAGE),
     RemoveDisk(230, QuotaDependency.STORAGE),
     MoveImageGroup(231, QuotaDependency.STORAGE),
-    GetDiskAlignment(232, QuotaDependency.NONE),
     AmendVolume(233, ActionGroup.EDIT_DISK_PROPERTIES, QuotaDependency.NONE),
     RemoveMemoryVolumes(234, QuotaDependency.NONE),
     RemoveDiskSnapshots(235, ActionGroup.MANIPULATE_VM_SNAPSHOTS, QuotaDependency.NONE),
@@ -189,6 +198,7 @@ public enum ActionType {
     CreateAllTemplateDisksFromSnapshot(251, QuotaDependency.NONE),
     UpdateVolume(253, QuotaDependency.NONE),
     UpdateAllTemplateDisks(254, QuotaDependency.NONE),
+    CreateSnapshotDisk(256, ActionGroup.MANIPULATE_VM_SNAPSHOTS, QuotaDependency.NONE),
 
     // VmPoolCommands
     AddVmPool(304, ActionGroup.CREATE_VM_POOL, QuotaDependency.BOTH),
@@ -252,7 +262,9 @@ public enum ActionType {
     DetachNetworkFromClusterInternal(710, false, QuotaDependency.NONE),
     UpdateNetworkOnCluster(711, ActionGroup.CONFIGURE_CLUSTER_NETWORK, false, QuotaDependency.NONE),
 
-    ManageNetworkClusters(712, ActionGroup.ASSIGN_CLUSTER_NETWORK, false, QuotaDependency.NONE),
+    ManageNetworkClusters(712, ActionGroup.ASSIGN_CLUSTER_NETWORK, QuotaDependency.NONE),
+    StartClusterUpgrade(713, ActionGroup.EDIT_CLUSTER_CONFIGURATION, false, QuotaDependency.NONE),
+    FinishClusterUpgrade(714, ActionGroup.EDIT_CLUSTER_CONFIGURATION, false, QuotaDependency.NONE),
 
     /**
      * MultiLevelAdministration
@@ -283,7 +295,7 @@ public enum ActionType {
     AddSANStorageDomain(910, ActionGroup.CREATE_STORAGE_DOMAIN, QuotaDependency.NONE),
     ExtendSANStorageDomain(911, ActionGroup.EDIT_STORAGE_DOMAIN_CONFIGURATION, QuotaDependency.NONE),
     ReconstructMasterDomain(913, QuotaDependency.NONE),
-    DeactivateStorageDomainWithOvfUpdate(914, ActionGroup.MANIPULATE_STORAGE_DOMAIN, QuotaDependency.NONE),
+    DeactivateStorageDomainWithOvfUpdate(914, ActionGroup.MANIPULATE_STORAGE_DOMAIN, false, QuotaDependency.NONE),
     ProcessOvfUpdateForStorageDomain(1902, ActionGroup.MANIPULATE_STORAGE_DOMAIN, QuotaDependency.NONE),
     CreateOvfVolumeForStorageDomain(1903, ActionGroup.MANIPULATE_STORAGE_DOMAIN, QuotaDependency.NONE),
     RecoveryStoragePool(915, ActionGroup.CREATE_STORAGE_POOL, QuotaDependency.NONE),
@@ -324,7 +336,6 @@ public enum ActionType {
     TransferDiskImage(1024, ActionGroup.EDIT_DISK_PROPERTIES, false, QuotaDependency.STORAGE),
     TransferImageStatus(1025, ActionGroup.EDIT_DISK_PROPERTIES, false, QuotaDependency.NONE),
     ScanStorageForUnregisteredDisks(1026, ActionGroup.MANIPULATE_STORAGE_DOMAIN, QuotaDependency.NONE),
-    AllocateImageGroupVolume(1027, QuotaDependency.STORAGE),
     CreateImagePlaceholder(1028, QuotaDependency.NONE),
     SyncImageGroupData(1029, QuotaDependency.NONE),
     CreateVolumeContainer(1030, QuotaDependency.STORAGE),
@@ -337,11 +348,12 @@ public enum ActionType {
     GlusterStorageGeoRepSyncInternal(1037, QuotaDependency.NONE),
     ScheduleGlusterStorageSync(1038, ActionGroup.MANIPULATE_GLUSTER_VOLUME, QuotaDependency.NONE),
     FenceVolumeJob(1039, QuotaDependency.STORAGE),
-    ReduceImage(1046, QuotaDependency.STORAGE),
+    ReduceImage(1046, ActionGroup.REDUCE_DISK, QuotaDependency.NONE),
 
     // Leases
     AddVmLease(1040, QuotaDependency.NONE),
     RemoveVmLease(1041, QuotaDependency.NONE),
+    GetVmLeaseInfo(1047, QuotaDependency.NONE),
 
     // Sync luns
     SyncAllStorageDomainsLuns(1042, QuotaDependency.NONE),
@@ -407,12 +419,17 @@ public enum ActionType {
     UpdateGlusterHostPubKeyToSlaveInternal(1447, ActionGroup.MANIPULATE_GLUSTER_VOLUME, QuotaDependency.NONE),
     DisableGlusterCliSnapshotScheduleInternal(1448, ActionGroup.MANIPULATE_GLUSTER_VOLUME, QuotaDependency.NONE),
     SetUpPasswordLessSSHInternal(1449, ActionGroup.MANIPULATE_GLUSTER_VOLUME, QuotaDependency.NONE),
+    ResetGlusterVolumeBrick(1455, ActionGroup.MANIPULATE_GLUSTER_VOLUME, QuotaDependency.NONE),
 
     // Scheduling Policy
     AddClusterPolicy(1450, ActionGroup.EDIT_STORAGE_POOL_CONFIGURATION, false, QuotaDependency.NONE),
     EditClusterPolicy(1451, ActionGroup.EDIT_STORAGE_POOL_CONFIGURATION, false, QuotaDependency.NONE),
     RemoveClusterPolicy(1452, ActionGroup.EDIT_STORAGE_POOL_CONFIGURATION, false, QuotaDependency.NONE),
     RemoveExternalPolicyUnit(1453, ActionGroup.EDIT_STORAGE_POOL_CONFIGURATION, false, QuotaDependency.NONE),
+
+    // Gluster events continued...
+    AddGlusterWebhookInternal(1454, QuotaDependency.NONE),
+
     // External events
     AddExternalEvent(1500, ActionGroup.INJECT_EXTERNAL_EVENTS, QuotaDependency.NONE),
 
@@ -423,8 +440,11 @@ public enum ActionType {
     TestProviderConnectivity(1603, false, QuotaDependency.NONE),
     ImportProviderCertificate(1604, false, QuotaDependency.NONE),
     AddNetworkOnProvider(1605, ActionGroup.CREATE_STORAGE_POOL_NETWORK, false, QuotaDependency.NONE),
+    AddNetworkWithSubnetOnProvider(1608, ActionGroup.CREATE_STORAGE_POOL_NETWORK, false, QuotaDependency.NONE),
     AddSubnetToProvider(1606, false, QuotaDependency.NONE),
     RemoveSubnetFromProvider(1607, false, QuotaDependency.NONE),
+    SyncNetworkProvider(1609, false, QuotaDependency.NONE),
+    AutodefineExternalNetwork(1610, false, QuotaDependency.NONE),
 
     AddWatchdog(1700, ActionGroup.EDIT_VM_PROPERTIES, QuotaDependency.NONE),
     UpdateWatchdog(1701, ActionGroup.EDIT_VM_PROPERTIES, QuotaDependency.NONE),
@@ -535,6 +555,27 @@ public enum ActionType {
     ThawVm(3218, ActionGroup.CONFIGURE_VM_STORAGE, QuotaDependency.NONE),
     RemoveCinderDiskVolume(3219, QuotaDependency.STORAGE),
 
+    // Managed Block Storage
+    AddManagedBlockStorageDomain(3230, ActionGroup.CREATE_STORAGE_DOMAIN, false, QuotaDependency.NONE),
+    AddManagedBlockStorageDisk(3231, ActionGroup.CONFIGURE_VM_STORAGE, QuotaDependency.NONE),
+    RemoveManagedBlockStorageDisk(3232, ActionGroup.CONFIGURE_VM_STORAGE, QuotaDependency.NONE),
+    ConnectManagedBlockStorageDevice(3233, ActionGroup.CONFIGURE_VM_STORAGE, QuotaDependency.NONE),
+    SaveManagedBlockStorageDiskDevice(3234, ActionGroup.CONFIGURE_VM_STORAGE, QuotaDependency.NONE),
+    DisconnectManagedBlockStorageDevice(3235, ActionGroup.CONFIGURE_VM_STORAGE, QuotaDependency.NONE),
+    GetConnectionInfoForManagedBlockStorageDisk(3236, ActionGroup.CONFIGURE_VM_STORAGE, QuotaDependency.NONE),
+    ExtendManagedBlockStorageDiskSize(3237, ActionGroup.CONFIGURE_VM_STORAGE, QuotaDependency.NONE),
+    GetManagedBlockStorageStats(3238, ActionGroup.CONFIGURE_VM_STORAGE, QuotaDependency.NONE),
+    CloneSingleManagedBlockDisk(3239, ActionGroup.CONFIGURE_VM_STORAGE, QuotaDependency.NONE),
+    RemoveAllManagedBlockStorageDisks(3240, ActionGroup.CONFIGURE_VM_STORAGE, QuotaDependency.NONE),
+    CreateManagedBlockStorageDiskSnapshot(3241, ActionGroup.CONFIGURE_VM_STORAGE, QuotaDependency.NONE),
+    RemoveManagedBlockStorageSnapshot(3242, ActionGroup.CONFIGURE_VM_STORAGE, QuotaDependency.NONE),
+    TryBackToManagedBlockSnapshot(3243, ActionGroup.CONFIGURE_VM_STORAGE, QuotaDependency.NONE),
+    RestoreAllManagedBlockSnapshots(3244, ActionGroup.CONFIGURE_VM_STORAGE, QuotaDependency.NONE),
+
+    // Incremental Backup
+    StartVmBackup(3300, ActionGroup.BACKUP_DISK, false, QuotaDependency.NONE),
+    StopVmBackup(3301, ActionGroup.BACKUP_DISK, false, QuotaDependency.NONE),
+
     // Host Devices
     RefreshHostDevices(4000, ActionGroup.MANIPULATE_HOST, false, QuotaDependency.NONE),
     RefreshHost(4001, ActionGroup.MANIPULATE_HOST, false, QuotaDependency.NONE),
@@ -546,6 +587,8 @@ public enum ActionType {
     RemoveNetworkAttachment(5203, ActionGroup.CONFIGURE_HOST_NETWORK, QuotaDependency.NONE),
     PersistentHostSetupNetworks(5204, QuotaDependency.NONE),
     SyncAllHostNetworks(5205, ActionGroup.CONFIGURE_HOST_NETWORK, QuotaDependency.NONE),
+    SyncAllClusterNetworks(5206, ActionGroup.CONFIGURE_HOST_NETWORK, QuotaDependency.NONE),
+    CopyHostNetworks(5207, ActionGroup.CONFIGURE_HOST_NETWORK, QuotaDependency.NONE),
 
     // Hosted Engine
     ImportHostedEngineStorageDomain(6000, false, QuotaDependency.NONE),
@@ -572,7 +615,7 @@ public enum ActionType {
     private int intValue;
     private ActionGroup actionGroup;
     private boolean isActionMonitored;
-    private static final HashMap<Integer, ActionType> mappings = new HashMap<>();
+    private static final Map<Integer, ActionType> mappings = new HashMap<>();
     private QuotaDependency quotaDependency;
     private boolean quotaDependentAsInternalCommand = false;
 
